# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.app_component_build import AppComponentBuild

class TestAppComponentBuild(unittest.TestCase):
    """AppComponentBuild unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppComponentBuild:
        """Test AppComponentBuild
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppComponentBuild`
        """
        model = AppComponentBuild()
        if include_optional:
            return AppComponentBuild(
                component_config_connection_id = '',
                component_id = '',
                created_at = '',
                created_by_id = '',
                git_ref = '',
                id = '',
                install_deploys = [
                    nuon.models.app/install_deploy.app.InstallDeploy(
                        build_id = '', 
                        component_id = '', 
                        component_name = '', 
                        created_at = '', 
                        created_by_id = '', 
                        id = '', 
                        install_component_id = '', 
                        install_deploy_type = 'release', 
                        install_id = '', 
                        release_id = '', 
                        status = '', 
                        status_description = '', 
                        updated_at = '', )
                    ],
                releases = [
                    nuon.models.app/component_release.app.ComponentRelease(
                        build_id = '', 
                        created_at = '', 
                        created_by_id = '', 
                        id = '', 
                        release_steps = [
                            nuon.models.app/component_release_step.app.ComponentReleaseStep(
                                component_release_id = '', 
                                created_at = '', 
                                created_by_id = '', 
                                delay = '', 
                                id = '', 
                                install_deploys = [
                                    nuon.models.app/install_deploy.app.InstallDeploy(
                                        build_id = '', 
                                        component_id = '', 
                                        component_name = '', 
                                        created_at = '', 
                                        created_by_id = '', 
                                        id = '', 
                                        install_component_id = '', 
                                        install_deploy_type = 'release', 
                                        install_id = '', 
                                        release_id = '', 
                                        status = '', 
                                        status_description = '', 
                                        updated_at = '', )
                                    ], 
                                requested_install_ids = [
                                    ''
                                    ], 
                                status = '', 
                                status_description = '', 
                                updated_at = '', )
                            ], 
                        status = '', 
                        status_description = '', 
                        total_release_steps = 56, 
                        updated_at = '', )
                    ],
                status = '',
                status_description = '',
                updated_at = '',
                vcs_connection_commit = nuon.models.app/vcs_connection_commit.app.VCSConnectionCommit(
                    author_email = '', 
                    author_name = '', 
                    component_config_connection_id = '', 
                    created_at = '', 
                    created_by_id = '', 
                    id = '', 
                    message = '', 
                    sha = '', 
                    updated_at = '', )
            )
        else:
            return AppComponentBuild(
        )
        """

    def testAppComponentBuild(self):
        """Test AppComponentBuild"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
